function analytical_solution = wave_equation_analytical(fom_rom, discretization)
    
    % Builds up the analytical solution for the wave equation based on the parameters
    % contained in the structures fom_rom and discretization.
    
    space = discretization.space.dx * (1:discretization.space.n_steps);
    time = discretization.time.dt * (0:1:discretization.time.n_steps-1);
    
    grid_minus = repmat(space', 1, discretization.time.n_steps) - repmat(fom_rom.parameter.c * time, discretization.space.n_steps, 1);
    
    grid_plus = repmat(space', 1, discretization.time.n_steps) + repmat(fom_rom.parameter.c * time, discretization.space.n_steps, 1);
    
    grid_minus = mod(grid_minus, discretization.space.length);
    grid_plus = mod(grid_plus, discretization.space.length);
    
    q_plus = @(x)( (1/(2*fom_rom.parameter.c)) * (fom_rom.parameter.c * fom_rom.initial_condition{1}(x, discretization.space.length) + (2-fom_rom.parameter.rho)*fom_rom.initial_condition{2}(x, discretization.space.length)) );

    q_minus = @(x)( (1/(2*fom_rom.parameter.c)) * (fom_rom.parameter.c*fom_rom.initial_condition{1}(x, discretization.space.length) - fom_rom.parameter.rho * fom_rom.initial_condition{2}(x, discretization.space.length)) );
    
    analytical_solution = [fom_rom.parameter.rho * (q_plus(grid_minus) + q_minus(grid_plus)); fom_rom.parameter.c * (q_plus(grid_minus) - q_minus(grid_plus))];
    
end
