function [first_singular_value, derivative] = minus_leading_singular_value(shift, discretization, offline, snapshot_matrix)

    % This is the cost functional that is evaluated for the burgers equation to determine a suitable path in the offline phase
    % of the shifted POD algorithm.
    
    if(nargout > 1)
        
        [shift_matrices, shift_matrices_derivative] = offline.shift_matrix_generator(discretization, shift);

        % The result of the call to shift_matrix needs to be squeezed here, since it is a tensor with one redundant dimension, since we only have one spatial dimension.
        shifted_snapshot_matrix = squeeze(shift_matrix(shift_matrices, snapshot_matrix, 1));

        [first_left_singular_vector, first_singular_value, first_right_singular_vector] = svds(shifted_snapshot_matrix, 1);

        derivative_of_shifted_snapshot_matrix = squeeze(shift_matrix(shift_matrices_derivative, snapshot_matrix, 1));

        if(isscalar(shift))
            derivative = -first_left_singular_vector' * derivative_of_shifted_snapshot_matrix * first_right_singular_vector;
        else
            derivative = -diag(first_right_singular_vector) * derivative_of_shifted_snapshot_matrix' * first_left_singular_vector;
        end
        
        first_singular_value = -first_singular_value;
        
    else
        
        shift_matrices = offline.shift_matrix_generator(discretization, shift);
        shifted_snapshot_matrix = squeeze(shift_matrix(shift_matrices, snapshot_matrix, 1));
        first_singular_value = -svds(shifted_snapshot_matrix, 1);
    end
    
end
