function [new_value, derivative_matrix] = steepest_descent(start_value, f, max_iterations, tolerance)

    % Steepest descent method for the determination of a suitable shift for the burgers
    % equation in the offline phase of the shifted pod algorithm.

    % Convert row to column.
    if(isrow(start_value))
        start_value = start_value';
    end

    % f needs to compute the function value and the derivative.
    [func_value, derivative] = f(start_value);
    new_value = start_value;
    derivative = -derivative;
    
    derivative_matrix = zeros(size(derivative,1), 1 + max_iterations);
    derivative_matrix(:,1) = derivative;
    
    for k = 1:max_iterations
        
        slope = linesearch(f, derivative, new_value, 0.5, 1e-4);
        new_value = new_value + slope * derivative;

        if(norm(f(new_value) - func_value) < tolerance)
            return
        end
        
        [func_value, derivative] = f(new_value);  
        derivative = -derivative;
        derivative_matrix(:,k+1) = derivative;

    end

    warning('The steepest descent iteration did not converge.')
    
end
