function [snapshot_matrix, computation_time, u_ode45, t_ode45, computation_time_ode45, u_ode23, t_ode23, computation_time_ode23] = compute_truth_solution_struct_array(fom, discretization, const_stepsize)

    % This function computes the full order solution for every set of parameters contained
    % in the structure arrays fom and discretization.
    % const_stepsize is a flag for the matlab ode solvers to return values at each grid point based on the discretization structure array.
    % If more than three outputs are requested, it also computes the solution with ode45 and ode23 solvers.

    n_simulations = length(fom);
    computation_time = zeros(1, n_simulations);
    
    snapshot_matrix = cell(1, n_simulations);
    if (nargout > 2)
        u_ode45 = cell(1, n_simulations);
        t_ode45 = cell(1, n_simulations);
        u_ode23 = cell(1, n_simulations);
        t_ode23 = cell(1, n_simulations);
        computation_time_ode45 = zeros(1, n_simulations);
        computation_time_ode23 = zeros(1, n_simulations);
    end
    
    for i = 1:n_simulations
        [D, DD] = create_finite_difference_matrix(discretization(i).order, discretization(i).boundary_condition, discretization(i).space.n_steps, discretization(i).space.dx);
        
        if (nargout > 2)
            [snapshot_matrix{i}, computation_time(i), u_ode45{i}, t_ode45{i}, computation_time_ode45(i), u_ode23{i}, t_ode23{i}, computation_time_ode23(i)] = compute_truth_solution(fom(i), discretization(i), D, DD, const_stepsize);
        else
            [snapshot_matrix{i}, computation_time(i)] = compute_truth_solution(fom(i), discretization(i), D, DD, const_stepsize);
        end
    end

end
