function relative_L2_online_error = compute_relative_L2_online_error(snapshot_matrix, shifted_pod_solution)

    % Computes the relative L2 error between snapshot_matrix and shifted_pod_solution under the assumption of periodic boundary
    % conditions for all snapshot matrices in the snapshot_matrix variable, which is assumed to be a cell 
    % that contains the snapshot matrices.
    % Note that shifted_pod_solution is assumed to be a cell that holds the approximations, and must be of the same length as 
    % snapshot_matrix.

    l1 = length(snapshot_matrix);
    l2 = length(shifted_pod_solution);

    if (l1 == l2)
        relative_L2_online_error = zeros(1, l1);
        for i = 1:l1
            relative_L2_online_error(i) = relative_L2_norm(snapshot_matrix{i}, snapshot_matrix{i} - shifted_pod_solution{i});
        end 
    else
        warning("No relative L2 online error will be computed since the number of full order solutions and the number of shifted pod solutions are not equal!");
    end

end
