function discretization = create_discretization_struct(equation, fom_rom, discretization_default)

        % This is a helper function that creates a struct array discretization with discretization parameters
        % for each struct that is contained in the struct array fom_rom. Some parameters may be influenced by 
        % passing the discretization_default struct, which should have the fields
        %
        % discretization_default.space.n_steps = whole positive number;
        % discretization_default.time.n_steps = whole positive number;

        n_structs = length(fom_rom);
    
        for i = 1:n_structs
            discretization(i) = struct();
        end
    
        for i = 1:n_structs
        
%              discretization(i).order = discretization_default.order;
            discretization(i).order = 6;
            discretization(i).boundary_condition = 'periodic';
            
            discretization(i).space.n_steps = discretization_default.space.n_steps;
%              discretization(i).space.length = discretization_default.space.length;
            discretization(i).space.length = 1;
            discretization(i).space.dx = discretization(i).space.length /discretization(i).space.n_steps;
            
            discretization(i).time.usecfl = false;
%              discretization(i).time.cfl = discretization_default.time.cfl;
            discretization(i).time.cfl = 1;
%              discretization(i).time.length = discretization_default.time.length;
            discretization(i).time.length = 1;
        
            switch equation
            
                case 'advection_reaction_diffusion'
                
                    if discretization(i).time.usecfl && fom(i).parameter.c ~= 0

                            discretization(i).time.dt = discretization(i).time.cfl * discretization(i).space.dx / abs(fom_rom(i).parameter.c);
                            
                            discretization(i).time.length = discretization(i).time.length / abs(fom_rom(i).parameter.c);
                            
                            discretization(i).time.n_steps = round(discretization(i).time.length / discretization(i).time.dt);
                            
                    else
                        discretization(i).time.n_steps = discretization_default.time.n_steps;
                        discretization(i).time.dt = discretization(i).time.length / discretization(i).time.n_steps;
                    end
                    
                case 'wave_equation'
                    if discretization(i).time.usecfl && fom(i).parameter.c ~= 0

                            discretization(i).time.dt = discretization(i).time.cfl * discretization(i).space.dx / abs(fom_rom(i).parameter.c);
                            
                            discretization(i).time.length = discretization(i).time.length / abs(fom_rom(i).parameter.c);
                            
                            discretization(i).time.n_steps = round(discretization(i).time.length / discretization(i).time.dt);
                            
                    else
                        discretization(i).time.n_steps = discretization_default.time.n_steps;
                        discretization(i).time.dt = discretization(i).time.length / discretization(i).time.n_steps;
                    end
                    
                case 'burgers'
                
                    discretization(i).time.n_steps = discretization_default.time.n_steps;
                    discretization(i).time.dt = discretization(i).time.length / discretization(i).time.n_steps;
                    
                otherwise
                    error("%s is not a known example!", equation);
                
            end
        
end
