function offline = create_offline_struct(equation, fom, discretization, offline_default)

    % Helper function that creates the offline struct that contains all relevant parameters
    % for the shifted pod offline phase. Some parameters may be injected by passing offline_default.

    offline.equation = equation;
    offline.n_modes = offline_default.n_modes;
    
    offline.n_error_modes_per_mode = 1;
    offline.shift_matrix_generator = @shift_matrix_generator_periodic;
    offline.n_cleaning_iterations = 40000;
    offline.lsqr.solver = 'backslash';
    offline.adaptive_mode_adding = false;
    offline.shift_direction = 1;

    switch fom(1).equation
        case 'advection_reaction_diffusion'
            offline.n_frames = 1;
            offline.naive_decomposition = 'simple_add';
            
        case 'wave_equation'
            offline.n_frames = 2;
            offline.naive_decomposition = 'simple_add';
            
        case 'burgers'
            offline.n_frames = 1;
            offline.naive_decomposition = 'subtract_and_conquer';
            
            % tolerance for steepest descent to find the paths
            offline.path_detection.tolerance = 10^(-6);
            % max iterations for steepest descent
            offline.path_detection.max_iterations = 200;
            % starting value, must be row vector of size space.n_steps * n_vars
            % Note: Even though fom might be a struct array, the way it is created does not allow for n_steps to change, same goes for discretization. Thus, we may determine the length of the starting vector only from the first entry of the respective struct arrays.
            offline.path_detection.starting_value = zeros(1, discretization(1).space.n_steps * fom(1).n_vars);
            % cost functional
            offline.path_detection.cost_functional = @minus_leading_singular_value;
            
        end

end
