function [modes, relative_error] = POD_offline(snapshot_matrix, n_modes, tolerance)
    
    % Function for the POD offline stage.
    % Compute n_modes from snapshot_matrix, if tolerance is set, then the algorithm takes as
    % many modes as are needed to obtain a relative offline error that is smaller than the tolerance,
    % even if a smaller number of modes is requested.
    
    [U, S, V] = svd(snapshot_matrix);
    
    if (nargin > 2)
        n_modes_tol = 1;
        modes = U(:, 1:n_modes_tol);
        coefficients = S(1:n_modes_tol) * V(:, 1:n_modes_tol)';
        approximation = modes * coefficients;
%          relative_error = norm(approximation - snapshot_matrix) / norm(snapshot_matrix);
        relative_error = relative_L2_norm(snapshot_matrix, approximation - snapshot_matrix);
        while (relative_error > tolerance && n_modes_tol < size(snapshot_matrix, 2))
            n_modes_tol = n_modes_tol + 1;
            modes = U(:, 1:n_modes_tol);
            coefficients = S(1:n_modes_tol, 1:n_modes_tol) * V(:, 1:n_modes_tol)';
            approximation = modes * coefficients;
            relative_error = norm(approximation - snapshot_matrix) / norm(snapshot_matrix);
        end
    else
        modes = U(:, 1:n_modes);
        coefficients = S(1:n_modes, 1:n_modes) * V(:, 1:n_modes)';
        approximation = modes * coefficients;
        relative_error = norm(approximation - snapshot_matrix) / norm(snapshot_matrix);
    end
    
end
