function [modes, min_rel_error] = POD_offline_struct_array(snapshot_matrix, n_modes, behaviour, tolerance)

    % Runs the POD offline phase for all snapshot matrices contained in the variable snapshot_matrix, which is assumed 
    % to be a cell.
    % The function has two modes which can be set via the behaviour variable:
    % either behaviour = 'normal', or 'sampling'.
    % 'normal' means that for each snapshot_matrix, n_modes modes are computed, 'sampling' means that
    % all snapshot matrices are concatenated and n_modes averaged modes are computed.

switch behaviour
    
    case 'normal'
    
        n_samples = length(snapshot_matrix);
        modes = cell(1, n_samples);
        min_rel_error = zeros(1, n_samples);
        
        if nargin > 3
            for i = 1:n_samples
                [modes{i}, min_rel_error(i)] = POD_offline(snapshot_matrix{i}, n_modes, tolerance);
            end
        else
            for i = 1:n_samples
                [modes{i}, min_rel_error(i)] = POD_offline(snapshot_matrix{i}, n_modes);
            end
        end
    
    case 'sampling'
    
        % Concatenate all snapshot matrices into one big matrix
        n_samples = length(snapshot_matrix);
        modes = cell(1,1);
        min_rel_error = cell(1,1);
        snapshot_matrix = cell2mat(snapshot_matrix);
        
        if nargin > 3
            [modes{1}, min_rel_error{1}] = POD_offline(snapshot_matrix, n_modes, tolerance);
        else
            [modes{1}, min_rel_error{1}] = POD_offline(snapshot_matrix, n_modes);
        end
        
    otherwise
        error("Behaviour %s is not a known behaviour for this method.", behaviour);
end

end
