function [POD_solution, reduced_state_matrix, computation_time, POD_solution_ode45, t_ode45, reduced_state_ode45, computation_time_ode45, POD_solution_ode23, t_ode23, reduced_state_ode23, computation_time_ode23] = POD_online_struct_array(fom_rom, discretization,  modes, const_stepsize);

    % This function computes the POD ROM solution for every set of parameters contained
    % in the structure arrays fom_rom and discretization.
    % const_stepsize is a flag for the matlab ode solvers to return values at each grid point based on the discretization structure array.
    % If more than three outputs are requested, it also computes the solution with ode45 and ode23 solvers.

    n_simulations = length(fom_rom);
    
    POD_solution = cell(1, n_simulations);
    reduced_state_matrix = cell(1, n_simulations);
    computation_time = zeros(1, n_simulations);
    
    % Two cases here, either n_sets_of_modes should be equal to n_simulations, or n_sets_of_modes is 1, since we are in the case that we work with parameter sampling and have averaged modes.
    n_sets_of_modes = length(modes);
    
    if n_sets_of_modes == 1
    
        if nargout > 3
        
            POD_solution_ode45 = cell(1, n_simulations);
            t_ode45 = cell(1, n_simulations);
            reduced_state_ode45 = cell(1, n_simulations);
            computation_time_ode45 = zeros(1, n_simulations);
            
            POD_solution_ode23 = cell(1, n_simulations);
            t_ode23 = cell(1, n_simulations);
            reduced_state_ode23 = cell(1, n_simulations);
            computation_time_ode23 = zeros(1, n_simulations);
            
            for i = 1:n_simulations
                [D, DD] = create_finite_difference_matrix(discretization(i).order, discretization(i).boundary_condition, discretization(i).space.n_steps, discretization(i).space.dx);
                
                [POD_solution{i}, reduced_state_matrix{i}, computation_time(i), POD_solution_ode45{i}, t_ode45{i}, reduced_state_ode45{i}, computation_time_ode45(i), POD_solution_ode23{i}, t_ode23{i}, reduced_state_ode23{i}, computation_time_ode23(i)] = POD_online(fom_rom(i).equation, modes{1}, discretization(i), fom_rom(i).parameter, fom_rom(i).initial_condition, D, DD, const_stepsize);
            end
            
        else
        
            for i = 1:n_simulations
                [D, DD] = create_finite_difference_matrix(discretization(i).order, discretization(i).boundary_condition, discretization(i).space.n_steps, discretization(i).space.dx);
                
                [POD_solution{i}, reduced_state_matrix{i}, computation_time(i)] = POD_online(fom_rom(i).equation, modes{1}, discretization(i), fom_rom(i).parameter, fom_rom(i).initial_condition, D, DD, const_stepsize);
            end
            
        end
            
    else
    
        if nargout > 3
        
            POD_solution_ode45 = cell(1, n_simulations);
            t_ode45 = cell(1, n_simulations);
            reduced_state_ode45 = cell(1, n_simulations);
            
            POD_solution_ode23 = cell(1, n_simulations);
            t_ode23 = cell(1, n_simulations);
            reduced_state_ode23 = cell(1, n_simulations);
            
            for i = 1:n_simulations
                [D, DD] = create_finite_difference_matrix(discretization(i).order, discretization(i).boundary_condition, discretization(i).space.n_steps, discretization(i).space.dx);
                
                [POD_solution{i}, reduced_state_matrix{i}, computation_time(i), POD_solution_ode45{i}, t_ode45{i}, reduced_state_ode45{i}, computation_time_ode45(i), POD_solution_ode23{i}, t_ode23{i}, reduced_state_ode23{i}, computation_time_ode23(i)] = POD_online(fom_rom(i).equation, modes{i}, discretization(i), fom_rom(i).parameter, fom_rom(i).initial_condition, D, DD, const_stepsize);
            end
            
        else
        
            for i = 1:n_simulations
                [D, DD] = create_finite_difference_matrix(discretization(i).order, discretization(i).boundary_condition, discretization(i).space.n_steps, discretization(i).space.dx);
                
                [POD_solution{i}, reduced_state_matrix{i}, computation_time(i)] = POD_online(fom_rom(i).equation, modes{i}, discretization(i), fom_rom(i).parameter, fom_rom(i).initial_condition, D, DD, const_stepsize);
            end
            
        end
    
    end

end
