function shifted_POD_system = multi_shift_reduce(discretization, shifted_POD_system, snapshot_matrix, n_modes)  

% Set nSubspaces as the number of subspaces, i.e. the number of frames

n_subspaces = shifted_POD_system.n_subspaces; 

sz = size(snapshot_matrix);
n_vars = sz(end-1);
n_steps_space_per_var = sz(1); % need to change if we ever go to higher dimensions.
n_steps_space = n_steps_space_per_var * n_vars;
n_steps_time = sz(end);
shift_direction = 1;

% Set the number of rows as the product of the number of spatial steps in
% each spatial dimension multiplied with the number of physical variables

n_rows = prod(n_steps_space_per_var) * n_vars; % could also write n_steps_space in case of 1D

%  Initialize the fields "sPODsystem.U", "s.PODsystem.V" and "sPODsystem.S"
%  as empty "column"-cells of with nSubSpaces entries. 

shifted_POD_system.U = cell(n_subspaces, 1);    
shifted_POD_system.V = cell(n_subspaces, 1);    
shifted_POD_system.S = cell(n_subspaces, 1);

% For each subspace (i.e. each spatial dimension), compute ...

for i = 1:n_subspaces
    
    % ... the shifted snapshot-tensor
    
    shifted_snapshot_matrix = shift_matrix(shifted_POD_system.shift_matrices{i}, snapshot_matrix, shift_direction);   
    
    % ... the reshaped shifted snapshot-tensor
    
    shifted_snapshot_matrix = reshape(shifted_snapshot_matrix, n_rows, n_steps_time); 
    
    % ... the singular-value-decomposition of size n_modes(i) of the reshaped shifted snapshot-tensor 
    
    [shifted_POD_system.U{i}, S, shifted_POD_system.V{i}] = svds(shifted_snapshot_matrix, n_modes(i));
    
    % Do some workaround because svds is broken.
    
    if(size(shifted_POD_system.U{i}, 2) ~= n_modes(i))
        [shifted_POD_system.U{i}, S, shifted_POD_system.V{i}] = svds(shifted_snapshot_matrix, n_modes(i) + 1);
    end
    
    % Set sPODsystem.S{i} as sparse S. 
    
    shifted_POD_system.S{i} = sparse(S);
    
end
