function W = compute_online_matrices_burgers(reduced_state, discretization, offline, modes, every_mode_with_own_shift, D, DD)

    % This function computes the ROM matrices for the shifted POD ROM for the burgers equation without using equivariance.

    n_steps_space = discretization.space.n_steps;
    shift_matrix_generator = offline.shift_matrix_generator;
    offset_vector = [0, cumsum(offline.n_modes)];
    
    n_total_modes = size(modes, 2);
    n_frames = offline.n_frames;
    
    n_rows = size(modes, 1);
    
    if (every_mode_with_own_shift)
        W = zeros(n_rows, n_total_modes + n_total_modes);
    else
        W = zeros(n_rows, n_total_modes + n_frames);
    end
    
    if (every_mode_with_own_shift)
        
        for i = 1:n_total_modes
            
            current_shift = reduced_state(n_total_modes + i);
            current_shift_matrices = shift_matrix_generator(discretization, current_shift);
            
            if (n_frames > 1)
                current_shift_matrix = kron(eye(n_frames), current_shift_matrices{1});
                diagD = kron(eye(n_frames), D);
            else
                current_shift_matrix = current_shift_matrices{1};
                diagD = D;
            end
            
            W(:,i) = current_shift_matrix * modes(:,i);
            W(:,n_total_modes + i) = current_shift_matrix * diagD * modes(:,i) * reduced_state(i);
            
        end
        
    else
    
        for i = 1:n_frames
            
            current_shift = reduced_state(n_total_modes + i);
            current_shift_matrices = shift_matrix_generator(discretization, current_shift);
        
            if (n_frames > 1)
                current_shift_matrix = kron(eye(n_frames), current_shift_matrices{1});
                diagD = kron(eye(n_frames), D);
            else
                current_shift_matrix = current_shift_matrices{1};
                diagD = D;
            end
            
            lower_index = offset_vector(i) + 1;
            upper_index = offset_vector(i + 1);
            
            W(:, lower_index:upper_index) = current_shift_matrix * modes(:, lower_index:upper_index);
            
            W(:, n_total_modes + i) = current_shift_matrix * diagD * modes(:, lower_index:upper_index) * reduced_state(lower_index:upper_index);

        end
        
    end
    
end
