function W = compute_online_matrices_burgers_equivariance(reduced_state, discretization, offline, modes, every_mode_with_own_shift, D, DD)

    % This function computes the ROM matrices for the shifted POD ROM for the burgers equation under use of equivariance.

    n_steps_space = discretization.space.n_steps;
    offset_vector = [0, cumsum(offline.n_modes)];
    
    n_total_modes = size(modes, 2);
    n_frames = offline.n_frames;
    
    n_rows = size(modes, 1);
    
    if (every_mode_with_own_shift)
        W = zeros(n_rows, n_total_modes + n_total_modes);
    else
        W = zeros(n_rows, n_total_modes + n_frames);
    end
    
    if (every_mode_with_own_shift)
        
        for i = 1:n_total_modes
            
            W(:,i) = modes(:,i);
            W(:,n_total_modes + i) = D * modes(:,i) * reduced_state(i);
            
        end
        
    else
    
        for i = 1:n_frames
            
            lower_index = offset_vector(i) + 1;
            upper_index = offset_vector(i + 1);
            
            W(:, lower_index:upper_index) = modes(:, lower_index:upper_index);
            
            W(:, n_total_modes + i) = D * modes(:, lower_index:upper_index) * reduced_state(lower_index:upper_index);

        end
        
    end
    
end
