function [left_online_matrix, right_online_matrix] = compute_online_matrices_equivariance(reduced_state, discretization, offline, modes, right_hand_side_matrix, every_mode_with_own_shift, D, DD)
    
    % This function computes the ROM matrices for the shifted POD ROM for linear equations, utilizing equivariance.
    
    n_steps_space = discretization.space.n_steps;
    offset_vector = [0, cumsum(offline.n_modes)];
    
    n_total_modes = size(modes, 2);
    n_frames = offline.n_frames;
    
    n_rows = size(modes, 1);
    
    if (every_mode_with_own_shift)
        W = zeros(n_rows, n_total_modes + n_total_modes);
    else
        W = zeros(n_rows, n_total_modes + n_frames);
    end
    
    if (every_mode_with_own_shift)
        
        for i = 1:n_total_modes
        
            if (n_frames > 1)
                diagD = kron(eye(n_frames), D);
            else
                diagD = D;
            end
            
            W(:,i) = modes(:,i);
            W(:,n_total_modes + i) = diagD * modes(:,i) * reduced_state(i);
            
        end
            
    else
            
        for i = 1:n_frames
            if (n_frames > 1)
                diagD = kron(eye(n_frames), D);
            else
                diagD = D;
            end
            
            lower_index = offset_vector(i) + 1;
            upper_index = offset_vector(i + 1);
            
            W(:, lower_index:upper_index) = modes(:, lower_index:upper_index);
            
            W(:, n_total_modes + i) = diagD * modes(:, lower_index:upper_index) * reduced_state(lower_index:upper_index);

        end
        
    end
    
    left_online_matrix = W'*W;
    
    if (every_mode_with_own_shift)
        right_online_matrix = W'*right_hand_side_matrix*[W(:,1:n_total_modes), zeros(n_rows, n_total_modes)];
    else
        right_online_matrix = W'*right_hand_side_matrix*[W(:,1:n_total_modes), zeros(n_rows, n_frames)];
    end
    
end
