function shifted_matrix = shift_matrix(shift_matrices, matrix, shift_direction, negative_velocity)

size_of_matrix = size(matrix);

% If matrix is a real matrix, and not a tensor ...
if(numel(size_of_matrix) == 2)
    % ... reshape the matrix to be a tensor to comply with the further structure of the program.
    matrix = reshape(matrix, size_of_matrix(1), 1, size_of_matrix(2));
    size_of_matrix = size(matrix);
end

n_steps_space = size_of_matrix(1);
n_vars = size_of_matrix(end-1); % The tensor entry just before the last one corresponds to the number of physical variables of the system. The last entry always corresponds to the time steps.
n_steps_time = size_of_matrix(end);
shifted_matrix = NaN(size_of_matrix); 

switch numel(size_of_matrix)
    
    case 3 % 1D
    
        % If we get 4 arguments, meaning the negativeVelocity flag has been passed ...
        if(nargin == 4)
            % ... and if the flag evaluates to true ...
            if(negative_velocity == true)
                % ... loop over the time steps ...
                for i = 1:n_steps_time
                    % ... and the number of physical variables ...
                    for j = 1:n_vars
                        % ... and shift the corresponding matrix (tensor) entry by multiplying it with the correct shift matrix. Before the multiplication happens, the shift matrix is rotated by 180 degrees. A rotation by 180 degrees effectively builds the inverse of the shift matrix, meaning the matrix is shifted in the opposite direction. 
                        shifted_matrix(:,j,i) = rot90(shift_matrices{i},2) * matrix(:,j,i); 
                    end
                end
                % ... and return.
                return
            end
        end
        
        % Loop over the time steps ...
        for i = 1:n_steps_time
            % ... and the physical variables ...
            for j = 1:n_vars
                % ... and shift the corresponding matrix (tensor) entry by multiplying it with the correct shift matrix.
                shifted_matrix(:,j,i) = shift_matrices{i} * matrix(:,j,i); 
            end
        end
        
    otherwise
        error('The variable <matrix> should have 3 to 5 dimensions!')
end
