function new_shifted_POD_system = best_fit_shifted_POD_system(discretization, offline, snapshot_matrix, combined_shifted_POD_system)

% The modes that have been determined for a low rank description.
U = combined_shifted_POD_system.U; 
V = combined_shifted_POD_system.V; 
n_subspaces = combined_shifted_POD_system.n_subspaces;  

%  n_vars = params.data.n_vars;
sz = size(snapshot_matrix);
n_steps_space_per_var = sz(1); % need to change if we ever go to higher dimensions
n_vars = sz(end-1);
n_steps_space = n_vars * n_steps_space_per_var;
%  n_steps_time = discretization.time.n_steps;
n_steps_time = sz(end);
n_error_modes_per_mode = offline.n_error_modes_per_mode;
n_modes = offline.n_modes;
%  n_modes = params.mode.n_modes;

% prod should only be needed if the spatial dimension is greater than 1.
n_discrete_vars = prod(n_steps_space_per_var) * n_vars;  
n_combined_modes = n_modes * (1 + n_error_modes_per_mode);
%  n_all_subpaces = sum(n_combined_modes); % I am not sure if the name of this variable is correct, since the number of subspaces is not equal to the sum of all modes.
n_rows = n_discrete_vars * n_steps_time;

n_total_modes = sum(n_combined_modes);
offset_vector = [0, cumsum(n_combined_modes)];

ansatz_space = NaN(n_rows, n_total_modes);   
co_moving_ansatz_space = NaN(n_rows, n_total_modes); 
%  index_offset = zeros(n_subspaces + 1, 1);

    % Loop over the number of subspaces (transports) ...
    for i = 1:n_subspaces
        
        % ... and the number of modes (regular modes + error modes) corresponding to the transport ...
        for j = 1:n_combined_modes(i)   
            
            % The end goal is to compute the alphas. From theory, the alphas should be given by S{i}*V{i}' from SVD. I think we take another approach here:
            
            % Compute the ansatz space for the i-th transport and the j-th mode as the product of the corresponding left and right singular vectors.
            ansatz_space_temp = U{i}(:,j) * V{i}(:,j)';
        
            % Write the result, after correctly reshaping it, to the corresponding column of the comoving ansatz space.
            co_moving_ansatz_space(:, offset_vector(i) + j) = reshape(ansatz_space_temp, n_rows, 1);
        
            % Reshape the ansatz space for the i-th transport and the j-th mode to comply with the further structure of the program ...
            ansatz_space_temp = reshape(ansatz_space_temp, n_steps_space_per_var, n_vars, n_steps_time);
            
            % Compute the ansatz space in the original frame by applying the inverse transformation (in this case a shift) to the comoving ansatz space.
            ansatz_space_temp_shifted_back = shift_matrix(combined_shifted_POD_system.shift_matrices{i}, ansatz_space_temp, 1, true);
            
            % Write the result, after correctly reshaping it, to the corresponding column of the original ansatz space.
            ansatz_space(:, offset_vector(i) + j) = reshape(ansatz_space_temp_shifted_back, n_rows, 1) ;
            
        end
%              indexOffset(i+1) = indexOffset(i)+nCombinedModes(i) ; 
    end

% Solve for the time dependent coefficients.

switch offline.lsqr.solver
    % Take note, since in the ansatz space, the V is incorporated, these alpha values will be different.
    case 'backslash'
        alpha = ansatz_space \ reshape(snapshot_matrix, [], 1);
% The lsqr case is not supported here.
%      case 'lsqr'
%          tolerance = offline.lsqr.tolerance;
%          max_iterations = offline.lsqr.max_iterations;
%          [alpha, ~] = lsqr(ansatz_space, reshape(snapshot_matrix, [], 1), tolerance, max_iterations);
    otherwise
        error('Unknown least squares solver.')
end

% Clear some variables
clear ansatz_space ansatz_space_temp

% Number of approximation components corresponds to number of subspaces.
shifted_POD_approximation_components = cell(n_subspaces, 1);

% Initialize the new sPOD system as the combined spod system.
new_shifted_POD_system = combined_shifted_POD_system; 

% Loop over the number of subspaces ...
for i = 1:n_subspaces
    % Get the current indices that indicate the current modes
    current_indices = offset_vector(i) + 1 : offset_vector(i + 1);
    % Multiply the comoving ansatz space with the coefficients and write the result to the approximation components.
    shifted_POD_approximation_components{i} = co_moving_ansatz_space(:, current_indices) * alpha(current_indices);
    
    % Compute new modes, singular values and V by applying a sparse SVD, where only as many eigenvalues as there are modes for the i-th transport are retained, to the approximation component (which is reshaped to be a matrix of appropriate size).
    [new_shifted_POD_system.U{i}, S, new_shifted_POD_system.V{i}] = svds(reshape(shifted_POD_approximation_components{i}, n_discrete_vars, n_steps_time), n_modes(i));

    % Set the new S as a sparse variant of the computed value above.
    new_shifted_POD_system.S{i} = sparse(S); 
end

end
