function [modes, offline, min_rel_error] = shifted_pod_offline(equation, snapshot_matrix, discretization, offline, parameter)

% This is the main function that determines the shifted POD modes for a given snapshot_matrix and equation, based on the values
% in the structs discretization, offline and parameter.

%% data generation

n_steps_time = size(snapshot_matrix, 2);
n_steps_space = size(snapshot_matrix, 1);

dt = discretization.time.dt;
dx = discretization.space.dx;

n_steps_space_per_var = discretization.space.n_steps;

n_modes = offline.n_modes;
n_vars = n_steps_space / n_steps_space_per_var;
time = dt * (0:1:n_steps_time-1);
space = dx * (1:n_steps_space_per_var);

switch equation
    case 'advection_reaction_diffusion'

        shift = time' * parameter.c;
        
    case 'wave_equation'

        shift = time' * [parameter.c, -parameter.c];
        
    case 'burgers'
    
        [shift, shift_derivative] = steepest_descent(offline.path_detection.starting_value, @(shift)offline.path_detection.cost_functional(shift, discretization, offline, snapshot_matrix), offline.path_detection.max_iterations, offline.path_detection.tolerance);
        
        if(isscalar(shift))
            shift = shift * time';
        end
        
        shift = shift - shift(1);
        
end

%% mode calculation
subspace_decomposition = @subspace_decomposition_by_shifted_POD_iteration;

[shifted_POD_system, shifted_snapshot_matrix, rel_errors] = subspace_decomposition(discretization, offline, snapshot_matrix, shift);
min_rel_error = min(rel_errors);

modes = zeros(n_steps_space, sum(n_modes));

helper = [0, cumsum(n_modes)];

for i = 1:length(n_modes)
    modes(:,helper(i)+1:helper(i+1)) = shifted_POD_system.U{i};
end

end
