function [shifted_POD_system, snapshot_matrix_approximation, relative_errors] = subspace_decomposition_by_shifted_POD_iteration(discretization, offline, snapshot_matrix, shift)  

n_steps_space_per_var = discretization.space.n_steps;
n_steps_space = size(snapshot_matrix, 1);
n_vars = n_steps_space / n_steps_space_per_var;
n_steps_time = size(snapshot_matrix, 2);

n_modes = offline.n_modes;
n_error_modes_per_mode = offline.n_error_modes_per_mode;
shift_matrix_generator = offline.shift_matrix_generator;

if (numel(size(snapshot_matrix)) == 2)
    snapshot_matrix = reshape(snapshot_matrix, n_steps_space_per_var, n_vars, n_steps_time);
end
    
naive_decomposition = offline.naive_decomposition;
error_measure = @relative_L2_norm;

min_number_iterations = 4;
range_of_decline_control = 6;
min_decline_factor = 0.01;

n_cleaning_iterations = offline.n_cleaning_iterations;
n_total_error_modes = n_modes * n_error_modes_per_mode;
relative_errors = zeros(n_cleaning_iterations + 1, 1); 

shifted_POD_system = init_shift_matrix(discretization, shift_matrix_generator, shift);
diff_system = shifted_POD_system; 

switch naive_decomposition
    
    case 'simple_add'
        
        shifted_POD_system = multi_shift_reduce(discretization, shifted_POD_system, snapshot_matrix, n_modes);
    
    case 'subtract_and_conquer'

        shifted_POD_system = multi_shift_reduce_and_subtract(discretization, shifted_POD_system, snapshot_matrix, n_modes); 
    
    otherwise
    
        error('Method for naive decomposition is unknown.')
        
end

snapshot_matrix_approximation = additive_subspace_combination(snapshot_matrix, discretization, shifted_POD_system, n_vars);

for l = 1:n_cleaning_iterations
    
    % Compute the difference between approximated snapshot matrix and original snapshot matrix.
    snapshot_matrix_diff = snapshot_matrix_approximation - snapshot_matrix;
    % measure the relative error of the approximation.
    relative_errors(l) = error_measure(snapshot_matrix, snapshot_matrix_diff);
    % Display the relative error.
%      disp(relative_errors(l))
    
    % If the minimum number of iterations has been exceeded ...
    if (l >= min_number_iterations)
        
        % ... and if the relative error has increased in the last two iterations ...
        if((relative_errors(l) >= relative_errors(l-1)) && (relative_errors(l-1) >= relative_errors(l-2)))
            % ... set the remaining entries to the value of the current relative error ...
            relative_errors(l+1:n_cleaning_iterations) = relative_errors(l);
            % ... and stop the cleaning.
            break
        end
        
        % ... and if 
        if(l >= max(min_number_iterations, range_of_decline_control + 1))
            if (relative_errors(l) >= relative_errors(l - range_of_decline_control) * (1 - min_decline_factor))
                relative_errors(l+1:n_cleaning_iterations) = relative_errors(l);
                break
            end
        end
        
    end
    
    diff_system = multi_shift_reduce(discretization, diff_system, snapshot_matrix_diff, n_total_error_modes); 
    
    shifted_POD_ansatz = combine_modes(shifted_POD_system, diff_system);
    shifted_POD_system = best_fit_shifted_POD_system(discretization, offline, snapshot_matrix, shifted_POD_ansatz);

    snapshot_matrix_approximation = additive_subspace_combination(snapshot_matrix, discretization, shifted_POD_system, n_vars);  
end

relative_errors(n_cleaning_iterations + 1) = error_measure(snapshot_matrix, snapshot_matrix_approximation - snapshot_matrix); 
disp(['Relative offline error (measured in L_2 norm): ' num2str(relative_errors(n_cleaning_iterations + 1))])
