function [shifted_POD_solution, reduced_state_matrix, computation_time, shifted_POD_solution_ode45, t_ode45, reduced_state_ode45, computation_time_ode45, shifted_POD_solution_ode23, t_ode23, reduced_state_ode23, computation_time_ode23] = shifted_pod_online_struct_array(fom_rom, discretization, offline, modes, every_mode_with_own_shift, use_equivariance, const_stepsize);

    % Computes the shifted POD ROM solution based on a self written time integration (implicit trapezoidal rule) of the equation 'equation' for all parameters in the
    % structure arrays fom_rom, discretization and the structure offline as well as the modes. 'const_stepsize' is a flag for the ode solvers to return solutions only at
    % the grid points specified by the parameters in discretization.
    % 'every_mode_with_own_shift' and 'use_equivariance' are flags that tell the function that every mode should get its own shift / equivariance should be used.
    % If more than three outputs are requested, this function also uses matlab ode45 and ode23 solvers to compute the full order solution.

    n_simulations = length(fom_rom);
    shifted_POD_solution = cell(1, n_simulations);
    reduced_state_matrix = cell(1, n_simulations);
    computation_time = zeros(1, n_simulations);
    
    % Two cases here, either n_sets_of_modes should be equal to n_simulations, or n_sets_of_modes is 1, since we are in the case that we work with parameter sampling and have averaged modes.
    n_sets_of_modes = length(modes);
    
    if n_sets_of_modes == 1
    
        if nargout > 3
        
            shifted_POD_solution_ode45 = cell(1, n_simulations);
            t_ode45 = cell(1, n_simulations);
            reduced_state_ode45 = cell(1, n_simulations);
            computation_time_ode45 = zeros(1, n_simulations);
            
            shifted_POD_solution_ode23 = cell(1, n_simulations);
            t_ode23 = cell(1, n_simulations);
            reduced_state_ode23 = cell(1, n_simulations);
            computation_time_ode23 = zeros(1, n_simulations);
            
            for i = 1:n_simulations
                [D, DD] = create_finite_difference_matrix(discretization(i).order, discretization(i).boundary_condition, discretization(i).space.n_steps, discretization(i).space.dx);
                
                [shifted_POD_solution{i}, reduced_state_matrix{i}, computation_time(i), shifted_POD_solution_ode45{i}, t_ode45{i}, reduced_state_ode45{i}, computation_time_ode45(i), shifted_POD_solution_ode23{i}, t_ode23{i}, reduced_state_ode23{i}, computation_time_ode23(i)] = shifted_pod_online(fom_rom(i).equation, modes{1}, discretization(i), offline, fom_rom(i).parameter, every_mode_with_own_shift, use_equivariance, fom_rom(i).initial_condition, D, DD, const_stepsize);
            end
            
        else
        
            for i = 1:n_simulations
                [D, DD] = create_finite_difference_matrix(discretization(i).order, discretization(i).boundary_condition, discretization(i).space.n_steps, discretization(i).space.dx);
                
                [shifted_POD_solution{i}, reduced_state_matrix{i}, computation_time(i)] = shifted_pod_online(fom_rom(i).equation, modes{1}, discretization(i), offline, fom_rom(i).parameter, every_mode_with_own_shift, use_equivariance, fom_rom(i).initial_condition, D, DD, const_stepsize);
            end
            
        end
            
    else
    
        if nargout > 3
        
            shifted_POD_solution_ode45 = cell(1, n_simulations);
            t_ode45 = cell(1, n_simulations);
            reduced_state_ode45 = cell(1, n_simulations);
            computation_time_ode45 = zeros(1, n_simulations);
            
            shifted_POD_solution_ode23 = cell(1, n_simulations);
            t_ode23 = cell(1, n_simulations);
            reduced_state_ode23 = cell(1, n_simulations);
            computation_time_ode23 = zeros(1, n_simulations);
            
            for i = 1:n_simulations
                [D, DD] = create_finite_difference_matrix(discretization(i).order, discretization(i).boundary_condition, discretization(i).space.n_steps, discretization(i).space.dx);
                
                [shifted_POD_solution{i}, reduced_state_matrix{i}, computation_time(i), shifted_POD_solution_ode45{i}, t_ode45{i}, reduced_state_ode45{i}, computation_time_ode45(i), shifted_POD_solution_ode23{i}, t_ode23{i}, reduced_state_ode23{i}, computation_time_ode23(i)] = shifted_pod_online(fom_rom(i).equation, modes{i}, discretization(i), offline, fom_rom(i).parameter, every_mode_with_own_shift, use_equivariance, fom_rom(i).initial_condition, D, DD, const_stepsize);
            end
            
        else
        
            for i = 1:n_simulations
                [D, DD] = create_finite_difference_matrix(discretization(i).order, discretization(i).boundary_condition, discretization(i).space.n_steps, discretization(i).space.dx);
                
                [shifted_POD_solution{i}, reduced_state_matrix{i}, computation_time(i)] = shifted_pod_online(fom_rom(i).equation, modes{i}, discretization(i), offline, fom_rom(i).parameter, every_mode_with_own_shift, use_equivariance, fom_rom(i).initial_condition, D, DD, const_stepsize);
            end
            
        end
    
    end

end
